@@ -1,11 +1,19 @@
-# Copyright (c) 2013-2018 by Ron Frederick <ronf@timeheart.net>.
-# All rights reserved.
+# Copyright (c) 2013-2018 by Ron Frederick <ronf@timeheart.net> and others.
 #
 # This program and the accompanying materials are made available under
-# the terms of the Eclipse Public License v1.0 which accompanies this
+# the terms of the Eclipse Public License v2.0 which accompanies this
 # distribution and is available at:
 #
-#     http://www.eclipse.org/legal/epl-v10.html
+#     http://www.eclipse.org/legal/epl-2.0/
+#
+# This program may also be made available under the following secondary
+# licenses when the conditions for such availability set forth in the
+# Eclipse Public License v2.0 are satisfied:
+#
+#    GNU General Public License, Version 2.0, or any later versions of
+#    that license
+#
+# SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later
 #
 # Contributors:
 #     Ron Frederick - initial implementation, API, and documentation
@@ -92,17 +100,30 @@ def _normalize_scoped_ip(addr):
     """Normalize scoped IP address
 
        The ipaddress module doesn't handle scoped addresses properly,
-       so we strip off the CIDR suffix here and normalize scoped IP
-       addresses using socket.inet_pton before we pass them into
-       ipaddress.
+       so we normalize scoped IP addresses using socket.getaddrinfo
+       before we pass them into ip_address/ip_network.
 
     """
 
-    for family in (socket.AF_INET, socket.AF_INET6):
-        try:
-            return socket.inet_ntop(family, socket.inet_pton(family, addr))
-        except (ValueError, socket.error):
-            pass
+    try:
+        addrinfo = socket.getaddrinfo(addr, None, family=socket.AF_UNSPEC,
+                                      type=socket.SOCK_STREAM,
+                                      flags=socket.AI_NUMERICHOST)[0]
+    except socket.gaierror:
+        return addr
+
+    if addrinfo[0] == socket.AF_INET6:
+        sa = addrinfo[4]
+        addr = sa[0]
+
+        idx = addr.find('%')
+        if idx >= 0: # pragma: no cover
+            addr = addr[:idx]
+
+        ip = ipaddress.ip_address(addr)
+
+        if ip.is_link_local:
+            addr = str(ipaddress.ip_address(int(ip) | (sa[3] << 96)))
 
     return addr
 
@@ -330,6 +351,18 @@ class SignalReceived(Exception):
         self.signal = signal
 
 
+class SoftEOFReceived(Exception):
+    """SSH soft EOF request received
+
+       This exception is raised on an SSH server stdin stream when the
+       client sends an EOF from within the line editor on the channel.
+
+    """
+
+    def __init__(self):
+        super().__init__('Soft EOF')
+
+
 class TerminalSizeChanged(Exception):
     """SSH terminal size change notification received
 
