@@ -1,11 +1,19 @@
-# Copyright (c) 2016 by Ron Frederick <ronf@timeheart.net>.
-# All rights reserved.
+# Copyright (c) 2016-2018 by Ron Frederick <ronf@timeheart.net> and others.
 #
 # This program and the accompanying materials are made available under
-# the terms of the Eclipse Public License v1.0 which accompanies this
+# the terms of the Eclipse Public License v2.0 which accompanies this
 # distribution and is available at:
 #
-#     http://www.eclipse.org/legal/epl-v10.html
+#     http://www.eclipse.org/legal/epl-2.0/
+#
+# This program may also be made available under the following secondary
+# licenses when the conditions for such availability set forth in the
+# Eclipse Public License v2.0 are satisfied:
+#
+#    GNU General Public License, Version 2.0, or any later versions of
+#    that license
+#
+# SPDX-License-Identifier: EPL-2.0 OR GPL-2.0-or-later
 #
 # Contributors:
 #     Ron Frederick - initial implementation, API, and documentation
@@ -272,7 +280,7 @@ class SSHLineEditor:
         """Erase character to the right, or send EOF if input line is empty"""
 
         if not self._line:
-            self._session.eof_received()
+            self._session.soft_eof_received()
         else:
             self._erase_right()
 
@@ -456,16 +464,17 @@ class SSHLineEditor:
         self._end_column = self._cursor
         self._draw_input()
 
+
 class SSHLineEditorChannel:
     """Input line editor channel wrapper
 
-       When creating server channels with ``line_editor`` set to ``True``,
+       When creating server channels with `line_editor` set to `True`,
        this class is wrapped around the channel, providing the caller with
        the ability to enable and disable input line editing and echoing.
 
        .. note:: Line editing is only available when a psuedo-terminal
                  is requested on the server channel and the character
-                 encoding on the channel is not set to ``None``.
+                 encoding on the channel is not set to `None`.
 
     """
 
@@ -497,11 +506,15 @@ class SSHLineEditorChannel:
            only full lines of input are sent to the session, and each
            line of input can be edited before it is sent.
 
-           :param bool line_mode:
+           :param line_mode:
                Whether or not to process input a line at a time
+           :type line_mode: `bool`
 
         """
 
+        self._orig_chan.logger.info('%s line editor',
+                                    'Enabling' if line_mode else 'Disabling')
+
         self._editor.set_line_mode(line_mode)
 
     def set_echo(self, echo):
@@ -510,11 +523,15 @@ class SSHLineEditorChannel:
            This method enables or disables echoing of input data when
            input line editing is enabled.
 
-           :param bool echo:
+           :param echo:
                Whether or not input to echo input as it is entered
+           :type echo: `bool`
 
         """
 
+        self._orig_chan.logger.info('%s echo',
+                                    'Enabling' if echo else 'Disabling')
+
         self._editor.set_echo(echo)
 
     def write(self, data, datatype=None):
@@ -529,7 +546,8 @@ class SSHLineEditorChannel:
 class SSHLineEditorSession:
     """Input line editor session wrapper"""
 
-    def __init__(self, orig_session):
+    def __init__(self, chan, orig_session):
+        self._chan = chan
         self._orig_session = orig_session
         self._editor = None
 
